@@ -1,9 +1,11 @@
 from collections import namedtuple
 
+from contracts_lib_py import utils
 from common_utils_py.agreements.service_agreement_template import ServiceAgreementTemplate
 from common_utils_py.agreements.service_types import ServiceTypes, ServiceTypesIndices
 from common_utils_py.ddo.service import Service
 from common_utils_py.utils.utilities import generate_prefixed_id
+from common_utils_py.utils.utilities import to_checksum_addresses
 
 Agreement = namedtuple('Agreement', ('template', 'conditions'))
 
@@ -50,10 +52,27 @@ class ServiceAgreement(Service):
 
         :return: Int
         """
+        price = 0
+        _amounts = self.get_param_value_by_name('_amounts')
+        for amount in _amounts:
+            price = price + int(amount)
+        # for cond in self.conditions:
+        #     for p in cond.parameters:
+        #         if p.name == '_amounts':
+        #             for amount in p.value:
+        #                 price = price + int(amount)
+        return price
+
+    def get_param_value_by_name(self, name):
+        """
+        Return the value from the conditions parameters given the param name.
+
+        :return: Object
+        """
         for cond in self.conditions:
             for p in cond.parameters:
-                if p.name == '_amount':
-                    return int(p.value)
+                if p.name == name:
+                    return p.value
 
     @property
     def service_endpoint(self):
@@ -221,11 +240,14 @@ class ServiceAgreement(Service):
             raise Exception(
                 'Error generating the condition ids, the service_agreement type is not valid.')
 
+        amounts = self.get_param_value_by_name('_amounts')
+        receivers = self.get_param_value_by_name('_receivers')
+        checksum_addresses = to_checksum_addresses(receivers)
         escrow_cond_id = keeper.escrow_reward_condition.generate_id(
             agreement_id,
             self.condition_by_name['escrowReward'].param_types,
-            [self.get_price(), publisher_address, consumer_address,
-             lock_cond_id, access_or_compute_id]).hex()
+            [amounts, checksum_addresses, publisher_address, lock_cond_id, access_or_compute_id]
+        ).hex()
 
         return access_or_compute_id, lock_cond_id, escrow_cond_id
 
